# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import test_sale_product_attribute_value_config
from . import test_sale_to_invoice
from . import test_sale_order
from . import test_sale_pricelist
from . import test_onchange
from . import test_reinvoice
from . import test_access_rights
from . import test_sale_refund
from . import test_sale_signature
from . import test_sale_transaction
